/*
 * Copyright 2019 Confluent Inc.
 *
 * Licensed under the Confluent Community License (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of the
 * License at
 *
 * http://www.confluent.io/confluent-community-license
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

package io.confluent.kafka.secretregistry.rest.exceptions;

import io.confluent.rest.exceptions.RestException;
import io.confluent.rest.exceptions.RestNotFoundException;

public class Errors {

  // HTTP 404
  public static final String PATH_NOT_FOUND_MESSAGE = "Path not found.";
  public static final int PATH_NOT_FOUND_ERROR_CODE = 40401;
  public static final String VERSION_NOT_FOUND_MESSAGE = "Version not found.";
  public static final int VERSION_NOT_FOUND_ERROR_CODE = 40402;
  public static final String KEY_NOT_FOUND_MESSAGE = "Key not found.";
  public static final int KEY_NOT_FOUND_ERROR_CODE = 40403;
  public static final String SECRET_NOT_FOUND_MESSAGE = "Secret not found";
  public static final int SECRET_NOT_FOUND_ERROR_CODE = 40404;

  // HTTP 422
  public static final int INVALID_VERSION_ERROR_CODE = 42201;
  public static final int OPERATION_NOT_PERMITTED_ERROR_CODE = 42202;

  // HTTP 500
  public static final int STORE_ERROR_CODE = 50001;
  public static final int OPERATION_TIMEOUT_ERROR_CODE = 50002;
  public static final int REQUEST_FORWARDING_FAILED_ERROR_CODE = 50003;
  public static final int UNKNOWN_MASTER_ERROR_CODE = 50004;
  // 50005 is used by the RestService to indicate a JSON Parse Error

  public static RestException pathNotFoundException() {
    return new RestNotFoundException(PATH_NOT_FOUND_MESSAGE, PATH_NOT_FOUND_ERROR_CODE);
  }

  public static RestException keyNotFoundException() {
    return new RestNotFoundException(KEY_NOT_FOUND_MESSAGE, KEY_NOT_FOUND_ERROR_CODE);
  }

  public static RestException versionNotFoundException() {
    return new RestNotFoundException(VERSION_NOT_FOUND_MESSAGE, VERSION_NOT_FOUND_ERROR_CODE);
  }

  public static RestException secretNotFoundException() {
    return new RestNotFoundException(SECRET_NOT_FOUND_MESSAGE, SECRET_NOT_FOUND_ERROR_CODE);
  }

  public static RestInvalidVersionException invalidVersionException() {
    return new RestInvalidVersionException();
  }

  public static RestException secretRegistryException(String message, Throwable cause) {
    return new RestSecretRegistryException(message, cause);
  }

  public static RestException storeException(String message, Throwable cause) {
    return new RestSecretRegistryStoreException(message, cause);
  }

  public static RestException operationTimeoutException(String message, Throwable cause) {
    return new RestSecretRegistryTimeoutException(message, cause);
  }

  public static RestOperationNotPermittedException operationNotPermittedException(String message) {
    return new RestOperationNotPermittedException(message);
  }

  public static RestException requestForwardingFailedException(String message, Throwable cause) {
    return new RestRequestForwardingException(message, cause);
  }

  public static RestException unknownMasterException(String message, Throwable cause) {
    return new RestUnknownMasterException(message, cause);
  }
}
