/*
 * Copyright 2019 Confluent Inc.
 *
 * Licensed under the Confluent Community License (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of the
 * License at
 *
 * http://www.confluent.io/confluent-community-license
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

package io.confluent.kafka.secretregistry.storage;

public enum SecretRegistryKeyType {
  SECRET("SECRET"),
  NOOP("NOOP"),
  DELETE_KEY("DELETE_KEY"),
  DELETE_PATH("DELETE_PATH");

  public final String keyType;

  private SecretRegistryKeyType(String keyType) {
    this.keyType = keyType;
  }

  public static SecretRegistryKeyType forName(String keyType) {
    for (SecretRegistryKeyType type : values()) {
      if (type.keyType.equals(keyType)) {
        return type;
      }
    }
    throw new IllegalArgumentException("Unknown secret registry key type : " + keyType);
  }
}

